@@ -71,6 +71,7 @@ mime_type = {
     "png": "image/png",
     "png_print": "image/png",
     "logodata": "text/plain",
+    "csv": "text/plain",
     "jpeg": "image/jpeg",
 }
 
@@ -81,6 +82,7 @@ extension = {
     "svg": "svg",
     "png_print": "png",
     "logodata": "txt",
+    "csv": "csv",
     "jpeg": "jpeg",
 }
 
@@ -115,12 +117,11 @@ class Field:
     def __init__(
         self,
         name: str,
-        default: Any = None,
-        conversion: Callable = None,
-        options: List[Any] = None,
+        default: Optional[Any] = None,
+        conversion: Optional[Callable] = None,
+        options: Optional[List[Any]] = None,
         errmsg: str = "Illegal value.",
     ) -> None:
-
         self.name = name
         self.default = default
         self.value = default
@@ -166,7 +167,7 @@ def float_or_none(value: Any) -> Optional[float]:
     return float(value)
 
 
-def main(htdocs_directory: str = None) -> None:
+def main(htdocs_directory: Optional[str] = None) -> None:
     logooptions = weblogo.LogoOptions()
 
     # A list of form fields.
@@ -180,7 +181,16 @@ def main(htdocs_directory: str = None) -> None:
             "format",
             "png",
             weblogo.formatters.get,
-            options=["png_print", "png", "jpeg", "eps", "pdf", "svg", "logodata"],
+            options=[
+                "png_print",
+                "png",
+                "jpeg",
+                "eps",
+                "pdf",
+                "svg",
+                "logodata",
+                "csv",
+            ],
             # TODO: Should copy list from __init__.formatters
             errmsg="Unknown format option.",
         ),
@@ -487,7 +497,9 @@ def main(htdocs_directory: str = None) -> None:
 
 
 def send_form(
-    controls: List[Field], errors: List[tuple] = None, htdocs_directory: str = None
+    controls: List[Field],
+    errors: Optional[List[tuple]] = None,
+    htdocs_directory: Optional[str] = None,
 ) -> None:
     if errors is None:
         errors = []
@@ -510,7 +522,7 @@ def send_form(
                 value = "auto"
             if value == "true":
                 substitutions[c.name] = "checked"
-            elif type(value) == bool:
+            elif type(value) is bool:
                 if value:
                     substitutions[c.name] = "checked"
                 else:
