@@ -99,7 +99,7 @@ def main() -> None:
     except ValueError as err:
         print("Error:", err, file=sys.stderr)
         sys.exit(2)
-    except KeyboardInterrupt:
+    except KeyboardInterrupt:  # pragma: no cover
         sys.exit(0)
 
 
@@ -417,7 +417,7 @@ def _build_option_parser() -> DeOptionParser:
         choices=formatters,
         metavar="FORMAT",
         help="Format of output: eps (default), png, png_print, pdf, jpeg, svg, "
-        "logodata",
+        "logodata, csv",
         default=default_formatter,
     )
 
