@@ -173,8 +173,8 @@ class Alphabet(object):
     # We're immutable, so use __new__ not __init__
     def __new__(
         cls,
-        letters: Union["Alphabet", str] = None,
-        alternatives: Tuple[Tuple[str, str], ...] = None,
+        letters: Optional[Union["Alphabet", str]] = None,
+        alternatives: Optional[Tuple[Tuple[str, str], ...]] = None,
     ) -> "Alphabet":
         """Create a new, immutable Alphabet.
 
@@ -283,7 +283,7 @@ class Alphabet(object):
 
     def chrs(self, sequence_of_ints: Sequence[int]) -> "Seq":
         """Convert a sequence of ordinals into an alphabetic string."""
-        c = [self._chr_table[n] for n in sequence_of_ints]
+        c = [self.chr(n) for n in sequence_of_ints]
         s = "".join(c)
         return Seq(s, self)
 
@@ -336,15 +336,15 @@ class Alphabet(object):
     def __iter__(self) -> Iterator[str]:
         return iter(self._letters)
 
-    def __getitem__(self, key: Any) -> str:
-        return self._letters[key]
+    # def __getitem__(self, key: Any) -> str:
+    #     return self._letters[key]
 
     def __hash__(self) -> int:
         return hash(tuple(self._ord_table))
 
     @staticmethod
     def which(
-        seqs: Union["Seq", "SeqList"], alphabets: List["Alphabet"] = None
+        seqs: Union["Seq", "SeqList"], alphabets: Optional[List["Alphabet"]] = None
     ) -> "Alphabet":
         """Returns the most appropriate unambiguous protein, RNA or DNA alphabet
         for a Seq or SeqList. If a list of alphabets is supplied, then the best alphabet
@@ -440,8 +440,8 @@ class Seq(str):
         cls,
         obj: str,
         alphabet: Optional[Alphabet] = generic_alphabet,
-        name: str = None,
-        description: str = None,
+        name: Optional[str] = None,
+        description: Optional[str] = None,
     ) -> "Seq":
         self = str.__new__(cls, obj)
         if alphabet is None:
@@ -476,7 +476,7 @@ class Seq(str):
         """
         return self.alphabet.ords(self)
 
-    def tally(self, alphabet: Alphabet = None) -> List[int]:
+    def tally(self, alphabet: Optional[Alphabet] = None) -> List[int]:
         """Counts the occurrences of alphabetic characters.
 
         Arguments:
@@ -620,7 +620,9 @@ class Seq(str):
         cls = self.__class__
         return cls(s, self.alphabet, self.name, self.description)
 
-    def words(self, k: int, alphabet: Alphabet = None) -> Generator[str, None, None]:
+    def words(
+        self, k: int, alphabet: Optional[Alphabet] = None
+    ) -> Generator[str, None, None]:
         """Return an iteration over all subwords of length k in the sequence. If an optional
         alphabet is provided, only words from that alphabet are returned.
 
@@ -640,7 +642,7 @@ class Seq(str):
             if alphabet is None or alphabet.alphabetic(word):
                 yield word
 
-    def word_count(self, k: int, alphabet: Alphabet = None) -> List:
+    def word_count(self, k: int, alphabet: Optional[Alphabet] = None) -> List:
         """Return a count of all subwords in the sequence.
 
         >>> from weblogo.seq import *
@@ -664,9 +666,9 @@ class SeqList(list):
     def __init__(
         self,
         alist: List[Seq] = [],
-        alphabet: Alphabet = None,
-        name: str = None,
-        description: str = None,
+        alphabet: Optional[Alphabet] = None,
+        name: Optional[str] = None,
+        description: Optional[str] = None,
     ):
         list.__init__(self, alist)
         self.alphabet = alphabet
@@ -694,7 +696,7 @@ class SeqList(list):
                 return False
         return True
 
-    def ords(self, alphabet: Alphabet = None) -> List[array]:
+    def ords(self, alphabet: Optional[Alphabet] = None) -> List[array]:
         """Convert sequence list into a 2D array of ordinals."""
         if not alphabet:
             alphabet = self.alphabet
@@ -705,7 +707,7 @@ class SeqList(list):
             k.append(alphabet.ords(s))
         return k
 
-    def tally(self, alphabet: Alphabet = None) -> List[int]:
+    def tally(self, alphabet: Optional[Alphabet] = None) -> List[int]:
         """Counts the occurrences of alphabetic characters.
 
         Arguments:
@@ -722,7 +724,7 @@ class SeqList(list):
         counts = [sum(c) for c in zip(*[s.tally(alphabet) for s in self])]
         return counts
 
-    def profile(self, alphabet: Alphabet = None):  # type: ignore  # Nasty circular import
+    def profile(self, alphabet: Optional[Alphabet] = None):  # type: ignore  # Nasty circular import
         """Counts the occurrences of characters in each column.
 
         Returns: Motif(counts, alphabet)
